// Setting dimensions and margins
const margin = { top: 40, right: 80, bottom: 60, left: 60 },
  width = 960 - margin.left - margin.right,
  height = 500 - margin.top - margin.bottom;

// Adding svg object to the top of the page
const svg = d3
  .select('#multi-line-chart')
  .append('svg')
  .attr('width', width + margin.left + margin.right)
  .attr('height', height + margin.top + margin.bottom)
  .append('g')
  .attr(
    'transform',
    `translate(${margin.left},${margin.top})`,
  );

// Reading the csv
d3.csv(
  'https://gist.githubusercontent.com/riyamathur1/9e6a69695dce47b51253ae50fdf87783/raw/637686002b0c59b5320a8506e4c4b199abde1581/atlanticstorms.csv',
).then((data) => {
  // Grouping data
  const sumstat = d3.group(data, (d) => d.year); // One array for each value of the X axis

  // Converting strings to nums
  data.forEach((d) => {
    d.frequency = +d.frequency;
    d.year = d3.timeParse('%Y')(d.year); // Parsing the year
  });

  // List of groups = header of csv files
  const keys = Array.from(new Set(data.map((d) => d.name)));

  // Title
  svg
    .append('text')
    .attr('x', width / 2)
    .attr('y', 0 - margin.top / 2)
    .attr('text-anchor', 'middle')
    .style('font-size', '20px')
    .style('text-decoration', 'underline')
    .text('Atlantic Storms Frequency Over Years');

  // X axis
  const x = d3
    .scaleTime()
    .domain(d3.extent(data, (d) => d.year))
    .range([0, width]);
  svg
    .append('g')
    .attr('transform', `translate(0, ${height})`)
    .call(d3.axisBottom(x).ticks(5));

  // Y axis
  const y = d3
    .scaleLinear()
    .domain([0, d3.max(data, (d) => +d.frequency)])
    .range([height, 0]);
  svg.append('g').call(d3.axisLeft(y));

  // Setting the color palette
  const color = d3
    .scaleOrdinal()
    .domain(keys)
    .range(['#e41a1c', '#377eb8', '#4daf4a']);

  // Drawing the lines
  const line = d3
    .line()
    .x((d) => x(d.year))
    .y((d) => y(+d.frequency));

  keys.forEach((key) => {
    let filteredData = data.filter((d) => d.name === key);
    svg
      .append('path')
      .datum(filteredData)
      .attr('fill', 'none')
      .attr('stroke', color(key))
      .attr('stroke-width', 1.5)
      .attr('d', line);
  });

  // Color legend
  const legend = svg
    .selectAll('.legend')
    .data(keys)
    .enter()
    .append('g')
    .attr('class', 'legend')
    .attr('transform', (d, i) => `translate(0,${i * 20})`);

  legend
    .append('rect')
    .attr('x', width - 18)
    .attr('width', 18)
    .attr('height', 18)
    .style('fill', color);

  legend
    .append('text')
    .attr('x', width - 24)
    .attr('y', 9)
    .attr('dy', '.35em')
    .style('text-anchor', 'end')
    .text((d) => d);

  // X axis label
  svg
    .append('text')
    .attr('text-anchor', 'end')
    .attr('x', width / 2)
    .attr('y', height + margin.top + 20)
    .text('Year');

  // Y axis label
  svg
    .append('text')
    .attr('text-anchor', 'end')
    .attr('transform', 'rotate(-90)')
    .attr('y', -margin.left + 20)
    .attr('x', -margin.top - height / 2 + 30)
    .text('Frequency');
});
